---
title: Contact Policy
---

**Effective 7 July 2024**

## 1. Support and Communication Channels

### 1.1 Public Support Channels

We offer FREE support through several PUBLIC channels, including:

- Community Forums
- Public GitHub Issues
- Open Discord Servers
- Social Media Platforms

These channels are ideal for:

- General inquiries about our projects
- Bug reports and feature requests
- Community discussions and knowledge sharing
- Open-source collaboration opportunities

### 1.2 Private Support Options

While we encourage the use of public channels, we understand that some situations may require private communication. Please note:

- Private support is a premium service and may be subject to fees.
- We reserve the right to invoice you for private support services.
- Billing is based on the anticipated workload for your query.
- Responses to private queries will be provided only after invoice payment is confirmed.

To request private support, please contact us through `support@nhcarrigan.com`.

### 1.3 Engagement Opportunities

Our platforms offer various ways to engage with our projects and community:

- Request support for technical issues
- Express interest in contributing to our open-source projects
- Seek mentorship in software development
- Participate in casual discussions with our team and community members

### 1.4 Platform Directory

Below, you'll find a comprehensive list of our official communication platforms. Each platform serves specific purposes and caters to different types of interactions. Please choose the most appropriate channel for your needs to ensure the fastest and most effective response.

## 2. Account Verification

### 2.1 List of Verified Accounts

We maintain a comprehensive list of all our verified accounts across different platforms. This list is regularly updated to reflect any changes or additions to our official online presence.

- View our verified accounts: https://cdn.nhcarrigan.com/socials.txt

### 2.2 GPG Key for Verification

To ensure the integrity of our verified accounts list, we use GPG (GNU Privacy Guard) encryption. You can download our public GPG key to verify the authenticity of the list.

- Download our GPG key: https://cdn.nhcarrigan.com/key.pgp

### 2.3 Verification Process

Follow these steps to verify the integrity of our verified accounts list:

- Download both the verified accounts list and our GPG key from the links provided above.
- Open a terminal or command prompt on your system.
- Navigate to the directory where you saved the files.
- Run the following command:

```
gpg -f /path/to/key --verify /path/to/socials
```

Replace `/path/to/key` with the path to the downloaded GPG key file, and `/path/to/socials` with the path to the downloaded verified accounts list.

If the verification is successful, you'll see a message confirming the signature is valid.

### 2.4 Importance of Verification

Verifying our accounts helps you:

- Avoid impersonation attempts
- Ensure you're interacting with official channels
- Protect yourself from potential scams or misinformation

### 2.5 Reporting Suspicious Accounts

If you encounter an account claiming to represent us but not listed in our verified accounts:

- Do not engage with or share sensitive information with the account
- Report the suspicious account to us immediately through one of our verified channels
- If possible, report the account to the platform it's on for impersonation

### 2.6 Staying Updated

We recommend checking our verified accounts list periodically, as we may add new official accounts or remove outdated ones. Always use the verification process to ensure you have the most current and authentic list.

## 3. Real-Time Communication Platforms

### 3.1 Discord Server

Our Discord server is the primary and most active platform for real-time communication.

- Join Link: https://chat.naomi.lgbt
- Features:
  - Fastest response times
  - Multiple topic-specific channels
  - Voice chat capabilities
  - Integration with our projects and bots
- Best for: Quick support, community discussions, and live collaboration

### 3.2 Matrix Space

For those who prefer an open-source alternative to Discord, we maintain a Matrix space.

- Join Link: https://matrix.to/#/#naomis:matrix.org
- Features:
  - Decentralized and open-source
  - End-to-end encryption for private messages
  - Cross-platform compatibility
- Best for: Privacy-conscious users and those who prefer open protocols

### 3.3 IRC Channels

For users who prefer traditional IRC, we maintain channels on LiberaChat.

- Network: LiberaChat
- Channels:
  - #nhcarrigan - Main support and discussion channel
  - #nhcarrigan-chat - Casual conversation and community chat
- Connection Guide: LiberaChat Connection Guide
- Features:
  - Lightweight and accessible from various clients
  - Suitable for users with limited bandwidth
  - Familiar interface for long-time internet users
- Best for: Users comfortable with traditional IRC interfaces and those seeking a minimal, text-based chat experience

### 3.4 Platform Choice Guidelines

- Discord: Recommended for most users, especially those seeking quick responses or community interaction.
- Matrix: Ideal for users prioritizing privacy and open-source solutions.
- IRC: Best for those who prefer a classic, lightweight chat experience or are using older hardware.

### 3.5 Etiquette and Best Practices

- Please be respectful and follow the community guidelines on all platforms.
- Use appropriate channels or rooms for your queries to ensure the fastest response.
- Before asking a question, check if it has been answered in pinned messages or FAQs.
- When seeking help, provide as much relevant information as possible.

## 4. Announcements and Updates

### 4.1 Reddit Board

Our Reddit board serves as the primary hub for official announcements and updates.

- URL: https://www.reddit.com/r/nhcarrigan/
- Nature: This board is read-only.
- Content:
  - Project updates and new releases
  - Important community announcements
  - Event notifications
  - Major policy changes
- Best for: Comprehensive, detailed announcements and long-form updates

### 4.2 Social Media Platforms

For more frequent and concise updates, we cross-post select announcements to our social media accounts.

#### 4.2.1 Twitter

- Account: @naomi_lgbt
- Content:
  - Brief announcements and updates
  - Quick tips and insights
  - Community engagement

#### 4.2.2 Mastodon

- Account: @naomi_lgbt@mastodon.social
- Content:
  - Similar to Twitter
  - Greater focus on personal activities

### 4.3 Interacting with Announcements

- Reddit: The board is read-only. For questions or discussions about announcements, please use our Discord server or other interactive platforms.
- Twitter and Mastodon: You can reply to posts or @mention us with questions or comments. We encourage community engagement on these platforms.

### 4.4 Best Practices for Staying Informed

- Subscribe to Multiple Channels: Each platform may have slightly different content. Following multiple channels ensures you don't miss any important updates.
- Enable Notifications: Consider enabling notifications for critical updates on your preferred platform.
- Regular Check-ins: If you prefer not to use notifications, we recommend checking these channels regularly, especially before starting work on or with our projects.
- Cross-Reference: Major announcements will typically be posted across all platforms. If you see something important on one channel, you can cross-reference it on others for any additional details.

### 4.5 Emergency or Critical Updates

For time-sensitive or critical announcements:

- We will use all available channels to ensure maximum reach.
- Such announcements will be clearly marked as urgent or critical.
- We may use additional notification methods (e.g., email for registered users) for extremely critical updates.

### 4.6 Historical Announcements

- All announcements on our Reddit board are archived and remain accessible for future reference.
- While social media posts may have limited visibility over time, all major announcements will be permanently available on Reddit.

## 5. Professional Engagement and Portfolio

### 5.1 LinkedIn Profile

LinkedIn serves as our primary professional networking platform.

- Profile URL: https://linkedin.com/in/naomi-lgbt
- Purpose:
  - Professional networking
  - Career history and accomplishments
  - Skills endorsements and recommendations
- Best for:
  - Potential employers or clients
  - Professional collaborators
  - Industry peers

#### 5.1.1 Connecting on LinkedIn

When sending a connection request, please include a brief message explaining your interest. We typically respond to LinkedIn messages within 2-3 business days.

### 5.2 Peerlist Profile

As an alternative to LinkedIn, we maintain a presence on Peerlist, a platform focused on tech professionals.

- Profile URL: https://peerlist.io/naomi_lgbt
- Purpose:
  - Showcase technical projects and contributions
  - Highlight specific skills and technologies
  - Connect with other tech professionals
- Best for:
  - Tech-focused recruiters and companies
  - Fellow developers and engineers
  - Open-source collaborators

#### 5.2.1 Engaging on Peerlist

Feel free to explore our projects and contributions on Peerlist. You can leave comments or questions on specific items in our portfolio.

### 5.3 Professional Inquiries

When reaching out for professional reasons, please consider the following:

- Clear Purpose: State the reason for your contact (e.g., job opportunity, collaboration, consultation).
- Relevant Background: Provide brief context about yourself or your company.
- Specific Questions: If you have particular queries, include them in your initial message.

### 5.4 Services

For details about our services and past work, visit our portfolio: https://nhcarrigan.com

### 5.5 Speaking Engagements and Events

If you're interested in having us speak at your event or contribute to your publication:

- Check our LinkedIn or Peerlist profiles for recent talks or articles.
- Reach out with specific details about your event or publication.
- Provide information about the audience, topic, and any other relevant details.

### 5.6 Keeping Professional Connections Updated

We regularly update our professional profiles with new projects, skills, and achievements. Follow us on these platforms to stay informed about our professional journey and potential opportunities for collaboration.

## 6. One-on-One Sessions

We offer personalized, one-on-one sessions to cater to various needs, from casual conversations to in-depth consultations. Book your session through our Topmate profile.

### 6.1 Coffee Chat

A casual, informal conversation to connect and share ideas.

- Duration: 15 minutes
- Purpose:
  - Get to know Naomi
  - Discuss general topics in tech
  - Share experiences and insights
- Best for:
  - Students looking for career advice
  - Professionals seeking to expand their network
  - Anyone interested in a friendly chat about tech and open source

### 6.2 Consulting Session

A focused, one-on-one session to discuss potential new projects and align our services with your needs.

- Duration: 30 minutes
- Purpose:
  - Explore your project requirements in detail
  - Discuss how our services can meet your needs
  - Provide estimated quotes for the proposed work
- Best for:
  - Developers stuck on a particular problem
  - Project managers seeking technical guidance
  - Startups needing expert input on their tech stack

### 6.3 Mentorship Session

An in-depth, personalized session focused on long-term professional growth and skill development.

- Duration: 1 hour
- Purpose:
  - Provide career guidance and development strategies
  - Offer personalized learning plans and resources
  - Review and provide feedback on code or projects
- Best for:
  - Early-career developers seeking guidance
  - Professionals looking to transition into tech
  - Anyone seeking structured, long-term professional development

### 6.4 How to Book a Session:

- Visit one of:
  - Our topmate profile: https://topmate.io/nhcarrigan
  - Our fiverr profile: https://www.fiverr.com/nhcarrigan
- Select the type of session you need (Coffee Chat, Consulting, or Mentorship)
- Select an available time slot
- Complete the booking process and payment

### 6.5 Preparing for Your Session:

- Coffee Chat: Come with topics you'd like to discuss or questions about the industry
- Consulting: Prepare a clear description of your problem or project, and any relevant code or documentation
- Mentorship: Outline your career goals and areas where you'd like to improve

### 6.6 Additional Information:

- All sessions are conducted virtually via a video call in our Discord server.
- Payment is required at the time of booking
- Rescheduling is possible with at least 24 hours notice

For any questions about these sessions or to discuss a different type of engagement, please reach out through our preferred contact methods listed in previous sections.

## 7. Email Communication

:::warning
Email communication is considered a paid service and will be invoiced.
:::

We offer several email addresses for specific types of inquiries. Please use the appropriate email address to ensure your message reaches the right team and receives the most efficient response.

### 7.1 General Inquiries

- Email: contact@nhcarrigan.com
- Use for:
  - General questions about our services or projects
  - Partnership or collaboration proposals
  - Media or press inquiries
  - Any queries that don't fit other categories

### 7.2 Billing and Financial Matters

- Email: billing@nhcarrigan.com
- Use for:
  - Questions about payments or invoices
  - Inquiries about outstanding balances
  - Refund requests
  - Updating billing information

### 7.3 Technical Support

- Email: support@nhcarrigan.com
- Use for:
  - Assistance with using our software or services
  - Reporting bugs or technical issues
  - Documentation clarifications

### 7.4 Privacy Concerns

- Email: privacy@nhcarrigan.com
- Use for:
  - Questions about our privacy policy
  - Requests for data access or deletion
  - Reporting potential privacy breaches
  - Opting out of data collection (where applicable)

### 7.5 Security Matters

- Email: security@nhcarrigan.com
- Use for:
  - Reporting security vulnerabilities
  - Questions about our security practices
  - Concerns about potential security breaches

### 7.6 Legal Inquiries

- Email: legal@nhcarrigan.com
- Use for:
  - Legal questions or concerns
  - Copyright or trademark issues
  - Requests for legal documentation
  - Formal notices or communications

### 7.7 Feedback and Suggestions

- Email: feedback@nhcarrigan.com
- Use for:
  - Providing feedback on our work or projects
  - Suggesting improvements or new features
  - Sharing your experience with our services
  - Offering ideas for future developments

### 7.8 Email Communication Guidelines

- Subject Line: Please use a clear, concise subject line that summarizes your inquiry.
- Content: Provide all relevant details in your initial email to expedite the response process.
- Attachments: If sending attachments, please mention them in the email body and ensure they are in common file formats.
- Response Time: We aim to respond to all emails within 2 business days. Complex inquiries may require additional time.
- Follow-ups: If you haven't received a response after 3 business days, feel free to send a polite follow-up.

### 7.9 Email Privacy and Security

All email communications are treated as confidential.

We do not share your email address or the content of your messages with third parties unless:
- Required by law; OR
- As part of a public warning related to a violation of our Code of Conduct

### 7.10 Spam and Unsolicited Emails

We have a strict no-spam policy. If you receive any unsolicited emails claiming to be from us, please report them to security@nhcarrigan.com.

By using the appropriate email address for your inquiry, you help us provide you with the most efficient and accurate response possible. If you're unsure which email to use, feel free to send your inquiry to contact@nhcarrigan.com, and we'll direct it to the appropriate team.

### 7.11 Acceptable Use and Consequences

We are committed to maintaining a respectful and productive communication environment. To ensure this:

- All email communications should be professional and respectful.
- Harassment, threats, or abusive language will not be tolerated.
- Spam or excessive unsolicited emails are prohibited.
- Attempting to use our email system for malicious purposes (e.g., phishing, spreading malware) is strictly forbidden.

:::danger[Attention!]
Abuse of our email system or violation of these guidelines will result in your email address being blocked from sending communications to any of our addresses. This block may be temporary or permanent, depending on the severity and frequency of the abuse.
:::

If you believe your email has been blocked in error, please contact us through an alternative method listed in this document to request a review of the situation.

We reserve the right to report serious abuses to relevant authorities if necessary.

By communicating with us via email, you agree to adhere to these guidelines and understand the consequences of misuse.
