---
title: Staff Handbook
---

**Effective 7 July 2024**

Welcome to our organization. This Staff Handbook serves as a comprehensive guide to our policies, procedures, and expectations. It is designed to help you understand your role in our community and how you can contribute to our collective success.

We rely on every staff member, regardless of position, to help keep our community running smoothly and efficiently. Your dedication, skills, and adherence to our standards are crucial in achieving our organizational goals.

By familiarizing yourself with this handbook and adhering to its guidelines, you play a vital role in maintaining the integrity and effectiveness of our organization. Your commitment to these principles helps ensure a positive, productive, and harmonious work environment for all.

## 1. Activity Requirements

### 1.1 Flexible Engagement

We recognize and deeply appreciate that our staff members are volunteers dedicating their time and effort to support our community. As such, we do not impose rigid activity quotas or specific engagement levels.

### 1.2 Communication of Extended Absences

While we maintain a flexible approach to activity, we kindly request that you inform us of any anticipated absences:

- For absences exceeding one week, please notify the team via the `#staff-chat` channel on Discord.
- This communication helps us manage workload distribution and ensures continued smooth operation of our community.

### 1.3 Extended Inactivity

In cases of prolonged inactivity:

- If you are inactive for more than one month without prior communication, we may remove you from the active staff team.
- This policy helps maintain an engaged and responsive staff roster.
- Please note that removal due to inactivity is not punitive and does not reflect negatively on your contributions.

### 1.4 Returning to the Team

We value your contributions and understand that life circumstances can change:

- If you've been removed due to inactivity, you are always welcome to rejoin the staff team when your schedule permits.
- To rejoin, please contact an admin.

### 1.5 Balancing Commitments

We encourage you to balance your volunteer work with your personal life and other commitments:

- Your well-being is important to us. Never feel pressured to overextend yourself.
- If you find your role becoming stressful or overly time-consuming, please discuss this with an admin.

### 1.6 Recognition of Contributions

While we don't set specific activity requirements, we do recognize and appreciate consistent engagement and contributions:

- Regular participation helps build a strong, cohesive community.
- Outstanding contributions may be acknowledged through our staff recognition program.

## 2. Moderator Guidelines

### 2.1 Role Definition

As a moderator, you occupy a position of trust within our community. This role comes with additional responsibilities and tools to ensure the safety and well-being of our community members. However, it's crucial to understand that:

- Being a moderator does not elevate you above other community members.
- Your role is one of service and support, not authority or superiority.

### 2.2 General Expectations

#### 2.2.1 Leading by Example

As moderators, you are expected to exemplify the ideal community member:

- Be active and engaged within the community.
- Strictly adhere to all community rules and guidelines.
- Demonstrate a welcoming and inclusive attitude towards all members, especially newcomers.

#### 2.2.2 Balancing Roles

Remember that you are both a moderator and a community member:

- Not every interaction requires a moderation action.
- Engage in regular social interactions with fellow community members.
- Maintain a balance between your moderator duties and personal enjoyment within the community.

#### 2.2.3 Platform Familiarity

Our community spans multiple platforms:

- You are entrusted with maintaining all our platforms, but you're not expected to be an expert on all of them.
- Focus on moderating platforms you're comfortable with.
- Seek assistance or guidance from fellow moderators when dealing with unfamiliar platforms.

### 2.3 Conduct Guidelines

#### 2.3.1 Professionalism

Maintain a professional demeanor in all interactions:

- Remain calm and objective, especially in challenging situations.
- Avoid engaging in or escalating conflicts.
- Use appropriate language and tone at all times.

#### 2.3.2 Fairness and Consistency

Apply rules and take actions consistently:

- Treat all community members equally, regardless of their status or your personal feelings.
- Make decisions based on community guidelines, not personal preferences.

#### 2.3.3 Transparency

Be open about your actions as a moderator:

- Clearly explain the reasons for any moderation decisions when appropriate.
- Be willing to discuss your actions with other moderators or admins if questions arise.

### 2.4 Collaboration and Support

#### 2.4.1 Team Communication

Maintain open lines of communication with your fellow moderators:

- Use designated channels (e.g., `#staff-chat`) to discuss moderation issues.
- Share experiences and seek advice when facing challenging situations.

#### 2.4.2 Continuous Learning

Stay informed and improve your moderation skills:

- Keep up-to-date with any changes to community guidelines or moderation policies.
- Participate in any provided training or skill-sharing sessions.

#### 2.4.3 Escalation Protocol

Know when and how to escalate issues:

- Identify situations that require input from administrators.
- Follow established procedures for escalating complex or sensitive matters.

### 2.2 Discord Moderation Guidelines

#### 2.2.1 General Principles

- Always approach situations calmly and objectively.
- Escalate gradually: Start with the least severe action necessary and progress as needed.
- Document all moderation actions using the mod bot for consistency and future reference.

#### 2.2.2 Warning a Member

Use warnings for minor infractions or first-time offenses.

**When to Warn:**
- Mild spam (e.g., posting the same message a few times)
- Non-discriminatory insults (e.g., "You're a jerk")
- Minor rule violations

**How to Warn:**
Use the mod bot command:
```txt
/warn @user [reason for warning]
```

**Follow-up:**
- Monitor the member's behavior after the warning.
- If behavior improves, no further action is needed.
- If issues persist, consider stronger measures.

#### 2.2.3 Kicking a Member

Kicking is a temporary removal that allows the member to rejoin.

**When to Kick:**
- Repeated minor infractions after warnings
- Arguing with moderators
- Moderate spam
- Non-severe rule violations

**How to Kick:**
Use the mod bot command:
```txt
/kick @user [reason for kick]
```

**Follow-up:**
- Monitor if the user returns and their subsequent behavior.
- Be prepared to take stronger action if issues continue upon their return.

#### 2.2.4 Banning a Member

Banning is the most severe action and should be used judiciously.

**When to Ban:**
- Severe rule violations
- Repeated offenses after warnings and kicks
- Malicious actions (e.g., raiding, doxxing, severe harassment)

**How to Ban:**
Use the mod bot command:
```txt
/ban @user [reason for ban]
```

**Important Considerations:**
- Discord bans are IP-specific.
- The member cannot rejoin until the ban is lifted.
- Always double-check the user and reason before banning.
- For permanent bans, consult with administrators.

#### 2.2.5 Moderation Best Practices

1. **Communication:** Clearly explain the reason for moderation actions to the affected member when possible.

2. **Consistency:** Apply rules uniformly to all members.

3. **Documentation:** Always use the mod bot for actions to ensure proper logging.

4. **Discretion:** Use your judgment. Context matters in deciding appropriate actions.

5. **Team Coordination:** Discuss unclear situations with fellow moderators.

6. **Appeals Process:** Be aware of the process for members to appeal moderation decisions.

7. **Continuous Learning:** Stay updated on any changes to community guidelines or moderation policies.

### 2.3 Twitch Moderation

#### 2.3.1 General Responsibilities

- Monitor chat actively during live streams.
- Enforce our community rules and Twitch's Terms of Service.
- Assist viewers with questions and foster a welcoming atmosphere.
- Support the streamer by managing chat flow and addressing issues promptly.

#### 2.3.2 Chat Moderation Tools

Familiarize yourself with Twitch's built-in moderation tools:

1. **Timeout:** Temporarily prevents a user from chatting.
2. **Ban:** Permanently removes a user from the channel.
3. **Delete Message:** Removes a single message from chat.
4. **Slow Mode:** Limits how often users can send messages.
5. **Followers-Only Mode:** Restricts chat to followers.
6. **Subscribers-Only Mode:** Limits chat to subscribers.
7. **Unique-Chat Mode:** Prevents users from posting duplicate messages.

#### 2.3.3 Moderation Actions

##### 2.3.3.1 Warnings

- For minor infractions, start with a verbal warning in chat.
- Use clear, concise language to explain the issue.

Example: "@User, please avoid spamming emotes. Next time may result in a timeout."

##### 2.3.3.2 Timeouts

Use timeouts for more serious or repeated minor offenses.

- First offense: 5-minute timeout
- Second offense: 10-minute timeout
- Third offense: 30-minute timeout

To timeout: `/timeout @username [duration]`

##### 2.3.3.3 Bans

Reserve bans for severe violations or persistent problematic behavior.

To ban: `/ban @username`

Always document the reason for bans in your moderator notes or designated channel.

#### 2.3.4 Specific Situations

1. **Spam:** Use timeouts, increasing duration for repeat offenses.
2. **Hate Speech/Discrimination:** Immediate ban and report to Twitch.
3. **Excessive Backseat Gaming:** Start with a warning, then short timeout if it continues.
4. **Spoilers:** Delete message and issue a warning.
5. **Self-Promotion:** Remove message and warn. Timeout for repeated offenses.
6. **Bot Attacks:** Enable followers-only or subscribers-only mode temporarily.

#### 2.3.5 Communication

- Coordinate with other moderators via a separate chat or Discord channel.
- Inform the streamer of any significant issues or decisions made during the stream.
- Be prepared to explain moderation actions if questioned by viewers.

#### 2.3.6 Raids and Hosting

- Welcome incoming raids positively.
- Be extra vigilant during raids to catch any potential influx of rule-breaking behavior.
- Assist in shouting out and thanking raiders/hosts as appropriate.

#### 2.3.7 Clips and Highlights

- Monitor clips created during streams for any inappropriate content.
- Report or delete any clips that violate our guidelines or Twitch ToS.

#### 2.3.8 Post-Stream Duties

- Review any user reports or issues that occurred during the stream.
- Discuss any notable incidents or concerns with the moderation team.
- Provide feedback or suggestions for improving stream moderation.

### 2.4 Reddit Moderation

#### 2.4.1 General Responsibilities

- Regularly check the moderation queue for reported posts and comments.
- Enforce subreddit rules and Reddit's content policy.
- Engage with the community to encourage positive interactions.
- Collaborate with other moderators to maintain consistency.

#### 2.4.2 Moderation Tools

Familiarize yourself with Reddit's moderation tools:

1. **Remove:** Takes down a post or comment from public view.
2. **Spam:** Removes content and marks it as spam.
3. **Approve:** Manually approves content, overriding auto-mod actions.
4. **Lock:** Prevents further comments on a post.
5. **Sticky:** Pins important posts to the top of the subreddit.
6. **Distinguish:** Marks your comment as coming from a moderator.
7. **Ban:** Prevents a user from posting or commenting in the subreddit.

#### 2.4.3 Moderation Actions

##### 2.4.3.1 Content Removal

- Remove posts and comments that violate subreddit rules or Reddit's content policy.
- Always provide a reason for removal, using removal reasons or commenting.

##### 2.4.3.2 User Warnings

- For minor infractions, issue a warning via modmail or comment.
- Document warnings in mod notes for future reference.

##### 2.4.3.3 Temporary Bans

- Use for repeated minor offenses or more serious rule violations.
- Typical durations: 3 days, 7 days, 14 days, 30 days.
- Always include the reason and duration in the ban message.

##### 2.4.3.4 Permanent Bans

- Reserve for severe violations or persistent problematic behavior.
- Always provide a clear reason in the ban message.
- Allow for appeal process through modmail.

#### 2.4.4 Specific Situations

1. **Spam:** Remove and mark as spam. Temp ban for repeated offenses.
2. **Harassment:** Remove, warn, and escalate to temp or permanent ban as needed.
3. **Off-topic Posts:** Remove and direct users to appropriate subreddits.
4. **Reposts:** Remove recent reposts, with a comment explaining the removal.
5. **Trolling:** Remove comments, warn, and ban for persistent behavior.
6. **Vote Manipulation:** Report to Reddit admins and remove content.

#### 2.4.5 AutoModerator

- Familiarize yourself with our AutoModerator configuration.
- Regularly review and update AutoMod rules as needed.
- Check the moderation log to ensure AutoMod is functioning correctly.

#### 2.4.6 Flair Management

- Ensure posts are properly flaired.
- Assist users with setting up user flairs if applicable.

#### 2.4.7 Modmail

- Respond to modmail inquiries promptly and professionally.
- Use templates for common responses to ensure consistency.
- Escalate complex issues to admins when necessary.

#### 2.4.8 Community Engagement

- Participate in discussions to set a positive example.
- Use distinguish feature judiciously when speaking officially as a moderator.
- Create and maintain community resources (FAQ, wiki, etc.).

#### 2.4.9 Coordinating with the Mod Team

- Use private moderator channels or subreddits for team discussions.
- Participate in periodic mod team meetings or discussions.
- Propose and discuss potential rule or policy changes.

#### 2.4.10 Handling Sensitive Content

- Remove NSFW content.
- For controversial topics, monitor discussions closely and lock if necessary.
- Report any illegal content to Reddit admins immediately.

### 2.5 Codeberg Moderation

#### 2.5.1 General Responsibilities

- Monitor repository activities, including issues, pull requests, and discussions.
- Enforce our organization's code of conduct and Codeberg's terms of service.
- Assist contributors with questions and foster a welcoming atmosphere for new participants.
- Manage repository settings and access controls.

#### 2.5.2 Moderation Tools

Familiarize yourself with Codeberg's moderation features:

1. **Issue Management:** Open, close, label, and moderate issues.
2. **Pull Request Review:** Review, comment on, and merge or reject pull requests.
3. **Commit Management:** Revert or cherry-pick commits if necessary.
4. **User Management:** Manage collaborator access and block problematic users.
5. **Repository Settings:** Adjust visibility, branch protection, and other settings.

#### 2.5.3 Moderation Actions

##### 2.5.3.1 Issue and Pull Request Moderation

- Review and triage new issues and pull requests promptly.
- Apply appropriate labels for categorization and priority.
- Close or merge after thorough review and discussion.

##### 2.5.3.2 Comment Moderation

- Remove inappropriate or off-topic comments.
- Provide warnings for minor infractions.
- Lock discussions that become unproductive or violate guidelines.

##### 2.5.3.3 User Management

- Grant appropriate access levels to contributors.
- Temporarily restrict access for users violating guidelines.
- Block persistent offenders after warnings and temporary restrictions.

#### 2.5.4 Specific Situations

1. **Spam:** Remove spam content and warn the user. Block for repeated offenses.
2. **Harassment:** Remove offending content, warn the user, and escalate to blocking if behavior persists.
3. **Off-topic Discussions:** Redirect to appropriate channels or close if irrelevant.
4. **Code of Conduct Violations:** Address promptly, following the enforcement guidelines in the CoC.
5. **Licensing Issues:** Ensure all contributions comply with the project's license. Remove any content that violates licensing terms.

#### 2.5.5 Repository Management

- Regularly review and update repository descriptions and README files.
- Manage branch protection rules to maintain code quality.

#### 2.5.6 Collaboration and Communication

- Use repository discussions or a designated communication channel for project-related conversations.
- Clearly communicate decisions and reasoning behind moderation actions.
- Encourage constructive feedback and open dialogue among contributors.

#### 2.5.7 Pull Request Review Process

- Establish and communicate clear guidelines for PR submissions.
- Conduct thorough code reviews, focusing on both functionality and style.
- Provide constructive feedback and guidance, especially for new contributors.
- Ensure all checks (e.g., tests, linting) pass before merging.

#### 2.5.8 Security Management

- Monitor and address security vulnerabilities promptly.
- Manage responsible disclosure of security issues.
- Regularly update dependencies to patch known vulnerabilities.

#### 2.5.9 Community Building

- Recognize and appreciate valuable contributions.
- Organize periodic community events or sprints to boost engagement.
- Maintain a welcoming atmosphere for contributors of all experience levels.

#### 2.5.10 Documentation

- Ensure project documentation is comprehensive and up-to-date.
- Encourage contributors to improve documentation alongside code changes.
- Maintain clear guidelines for project structure, coding standards, and contribution processes.

### 2.6 IRC Moderation

#### 2.6.1 General Responsibilities

- Monitor channel activities continuously while online.
- Enforce channel rules and network policies.
- Assist users with questions and foster a welcoming atmosphere.
- Manage channel modes and user privileges as needed.

#### 2.6.2 IRC-Specific Moderation Tools

Familiarize yourself with these essential IRC commands:

1. `/kick <nick> [reason]`: Remove a user from the channel temporarily.
2. `/ban <mask>`: Ban a user or hostmask from the channel.
3. `/mute <nick>`: Prevent a user from speaking in the channel.
4. `/topic`: Set or modify the channel topic.
5. `/mode`: Change channel modes (e.g., moderated, invite-only).

#### 2.6.3 Moderation Actions

##### 2.6.3.1 Warnings

For minor infractions, start with a verbal warning in the channel.

Example: "Username, please avoid using excessive caps. It's considered shouting."

##### 2.6.3.2 Kicks

Use kicks for more serious or repeated minor offenses.

To kick: `/kick username Reason for kick`

##### 2.6.3.3 Bans

Reserve bans for severe violations or persistent problematic behavior.

To ban: `/ban username*!*@*`

Always document the reason for bans in your moderation logs.

#### 2.6.4 Specific Situations

1. **Spam**: Use kicks, escalating to short-term bans for repeat offenses.
2. **Offensive Language**: Warn, then kick. Ban for repeated offenses.
3. **Flooding**: Mute temporarily, kick if behavior continues.
4. **Off-topic Discussions**: Gently redirect to appropriate channels.
5. **Bot Attacks**: Set channel to moderated mode (+m) temporarily.

#### 2.6.5 Channel Management

- Regularly update channel topics with important information or rules.
- Manage channel modes to maintain order (e.g., +m for moderated discussions).
- Coordinate with other ops to ensure consistent coverage and enforcement.

#### 2.6.6 User Support

- Be responsive to user queries about channel rules or IRC usage.
- Guide new users on proper IRC etiquette and our community standards.

#### 2.6.7 Logging and Reporting

- Maintain logs of significant moderation actions for team review.
- Report any serious incidents or patterns to admins.

### 2.7 Slack Moderation

#### 2.7.1 General Responsibilities

- Monitor channel activities across public channels.
- Enforce workspace rules and Slack's terms of service.
- Assist users with questions and foster a collaborative atmosphere.
- Manage channel settings and user permissions as needed.

#### 2.7.2 Slack-Specific Moderation Tools

Familiarize yourself with these essential Slack moderation features:

1. Message deletion: Remove inappropriate messages.
2. User management: Adjust user roles and permissions.
3. Channel management: Create, archive, or modify channel settings.
4. Workspace settings: Configure global settings for the workspace.

#### 2.7.3 Moderation Actions

##### 2.7.3.1 Warnings

For minor infractions, start with a private message to the user.

Example: "Hi [Username], please remember to use threads for extended discussions to keep the main channel clear. Thanks!"

##### 2.7.3.2 Message Removal

Use message deletion for content that violates workspace rules.

##### 2.7.3.3 Restricting Privileges

For repeated offenses, consider restricting user privileges temporarily.

##### 2.7.3.4 Removing Users

In severe cases, remove users from the workspace. This should be a last resort.

#### 2.7.4 Specific Situations

1. **Off-topic discussions**: Gently redirect to appropriate channels.
2. **Inappropriate content**: Remove the content and privately message the user.
3. **Spam**: Delete spam messages and restrict user privileges if persistent.
4. **Heated arguments**: Intervene privately to de-escalate and remind users of conduct guidelines.
5. **Sensitive information sharing**: Quickly remove any posts containing sensitive data and follow up with the user.

#### 2.7.5 Channel Management

- Regularly review and update channel purposes and topics.
- Archive inactive channels to keep the workspace organized.
- Ensure channels have appropriate permissions set.

#### 2.7.6 User Support

- Be responsive to user queries about workspace rules or Slack usage.
- Guide new users on Slack etiquette and our community standards.
- Assist with general troubleshooting of Slack features.

#### 2.7.7 Logging and Reporting

- Utilize Slack's built-in logs for auditing purposes.
- Report any serious incidents or patterns to admins.

#### 2.7.8 Integration Management

- Monitor and manage third-party app integrations to ensure they're used appropriately.
- Be prepared to troubleshoot or disable problematic integrations.


### 2.8 Matrix Moderation

#### 2.8.1 General Responsibilities

- Monitor room activities across our Matrix spaces.
- Enforce room rules and the Matrix.org Terms of Service.
- Assist users with questions and foster an inclusive atmosphere.
- Manage room settings and user power levels as needed.

#### 2.8.2 Matrix-Specific Moderation Tools

Familiarize yourself with these essential Matrix moderation features:

1. Redaction: Remove inappropriate messages.
1. Kick/Ban: Remove users temporarily or permanently from rooms.
1. Room settings: Modify room join rules, visibility, and other parameters.

#### 2.8.3 Moderation Actions

##### 2.8.3.1 Warnings

For minor infractions, start with a private message to the user.

Example: "Hi @username:domain.com, please remember to stay on-topic in #general. Thanks for your cooperation!"

##### 2.8.3.2 Message Redaction

Use redaction for content that violates room rules or Matrix ToS.

##### 2.8.3.3 Kicks and Bans

In severe cases, kick or ban users from the room. Use bans sparingly and for serious violations.

#### 2.8.4 Specific Situations

1. **Spam**: Redact spam messages and lower user power level if persistent.
2. **Offensive content**: Redact the content and privately message the user.
3. **Off-topic discussions**: Gently redirect to appropriate rooms or spaces.
4. **Bridged content issues**: Address issues specific to bridged networks (e.g., IRC, Discord) appropriately.
5. **End-to-end encrypted rooms**: Be aware of limitations in moderating e2ee rooms.

#### 2.8.5 Room Management

- Regularly review and update room topics and info.
- Manage room aliases and directory visibility.
- Ensure rooms have appropriate power level settings.

#### 2.8.6 User Support

- Be responsive to user queries about room rules or Matrix usage.
- Guide new users on Matrix etiquette and our community standards.
- Assist with general troubleshooting of Matrix clients and features.

#### 2.8.7 Logging and Reporting

- Utilize Matrix's event logs for auditing purposes where necessary.
- Report any serious incidents or patterns to admins.

#### 2.8.8 Federation Management

- Be aware of federation status with other homeservers.
- Know how to contact admins of other homeservers if inter-server issues arise.

## 3. Working With Fellow Moderators

### 3.1 Communication Channels

#### 3.1.1 Primary Communication Platform
- Discord serves as our primary communication hub for the moderation team.
- A private `#staff-chat` channel is available for internal discussions.

#### 3.1.2 Use of Staff Chat
- Utilize the `#staff-chat` channel for:
  - Discussing concerns
  - Seeking advice on handling situations
  - Requesting assistance with ongoing issues
  - Sharing relevant information with the team

### 3.2 Collaborative Problem-Solving

- Approach fellow moderators for help and insights when needed.
- Be open to offering assistance when others request it.
- Engage in constructive discussions to find optimal solutions.

### 3.3 Team Unity and Public Image

- Maintain a united front in public spaces.
- Avoid disagreeing with or criticizing fellow moderators in public forums.
- If you have concerns about a moderation action or a colleague's behavior:
  - Address the issue privately in the staff chat or through direct messages.
  - Seek resolution through open and respectful dialogue.

### 3.4 Conflict Resolution

- If unable to resolve disagreements among yourselves:
  - Escalate the matter to Naomi for guidance.
  - Present the situation objectively, providing necessary context.

### 3.5 Supporting Each Other

- Recognize that moderation can be challenging.
- Offer emotional support and encouragement to fellow moderators.
- Share experiences and coping strategies for dealing with difficult situations.

### 3.6 Knowledge Sharing

- Use the staff chat to share useful resources, tools, or techniques.
- Discuss emerging trends or patterns in user behavior that may require attention.

### 3.7 Consistency in Moderation

- Regularly discuss and align on interpretation and enforcement of community rules.
- Share examples of how you've handled specific situations to ensure consistency.

### 3.8 Respecting Privacy

- Keep all discussions in staff channels confidential.
- Do not share private moderator conversations with community members.

### 3.9 Active Participation

- Regularly check and engage in staff communications.
- Contribute to team discussions and decision-making processes.

### 3.10 Continuous Improvement

- Be open to feedback from fellow moderators.
- Suggest improvements to moderation processes or team communication.
- Participate in any team training or development activities.

## 4. Logging Sanctions

### 4.1 Discord Sanctions

- Moderation actions on Discord are automatically logged by our system.
- No additional manual logging is required for Discord-specific actions.

### 4.2 Sanctions on Other Platforms

For all platforms other than Discord, manual logging is necessary:

#### 4.2.1 Logging Channel
- Use the `#mod-logs` channel in our Discord community for logging all non-Discord sanctions.

#### 4.2.2 Required Information
When logging a sanction, include the following details:

1. Platform: Specify the platform where the action was taken (e.g., Twitch, Reddit, Codeberg).
2. Username: Provide the exact username or handle of the sanctioned member.
3. Reason: Clearly state the reason for the sanction, referencing specific rule violations if applicable.
4. Evidence: Include or describe any relevant evidence supporting the action taken.
5. Action Taken: Specify the type of sanction (e.g., warning, temporary ban, permanent ban).
6. Duration: For temporary sanctions, note the duration.

#### 4.2.3 Logging Format
Use the following format for consistency:

```
Platform: [Platform Name]
User: [Username]
Action: [Type of Sanction]
Duration: [If applicable]
Reason: [Detailed explanation]
Evidence: [Description or link to evidence]
```

### 4.3 Best Practices for Sanction Logging

1. **Timeliness**: Log the sanction as soon as possible after taking action.
2. **Objectivity**: Stick to facts and avoid personal opinions in the log.
3. **Clarity**: Ensure your log entry is clear and understandable to other moderators.
4. **Completeness**: Include all relevant information, even if it seems minor.
5. **Confidentiality**: Do not share logs outside of the moderation team.

### 4.4 Using Logged Information

- Regularly review logs to identify patterns or recurring issues.
- Use logged information to ensure consistent application of rules across platforms.
- Refer to logs when discussing moderation strategies or updating community guidelines.

### 4.5 Correcting or Updating Logs

- If you need to correct or update a logged sanction, do so in the same channel.
- Clearly mark your message as an update or correction to a previous log entry.

### 4.6 Reviewing Logs

- Administrators should periodically review sanction logs to ensure:
  - Consistency in moderation across the team
  - Proper documentation of all actions
  - Identification of any trends or areas needing attention

## 5. User Support

### 3.1 Role in User Experience

As a member of our team, you play a crucial role in ensuring a positive and smooth user experience across all our platforms. Your ability to provide timely and accurate support is essential to our community's satisfaction and growth.

### 5.2 Knowledge Base

- Familiarize yourself with most of our projects to answer a wide range of questions.
- Stay updated on recent changes or updates to our projects.
- Utilize available resources (documentation, FAQs, wikis) to assist users effectively.

### 5.3 Handling User Inquiries

#### 5.3.1 Immediate Assistance
- Respond promptly to users seeking help on any of our platforms.
- Provide clear, concise answers to questions you're confident about.

#### 5.3.2 Complex Inquiries
- For questions you're unsure about, don't hesitate to seek help.
- Inform the user that you're looking into their issue to manage expectations.

### 5.4 Collaborative Problem-Solving

- Utilize the staff chat in Discord for discussing complex user questions.
- Engage with fellow staff members to collaboratively find solutions.
- Share knowledge and insights to improve the team's overall support capabilities.

### 5.5 Follow-up

- After providing a solution, check if the user's issue has been fully resolved.
- Encourage users to reach out again if they need further assistance.

### 5.6 Continuous Improvement

- Keep track of common user issues and suggest improvements to our documentation or user interfaces.
- Share insights gained from user interactions with the rest of the team to enhance our overall support quality.

## 6. Contributor Support

### 6.1 Welcoming New Contributors

- Greet new contributors warmly when they show interest in our projects.
- Provide guidance on where to find our contribution guidelines and code of conduct.
- Offer assistance in identifying suitable first issues or tasks for newcomers.

### 6.2 Technical Assistance

- Help contributors set up their development environments.
- Provide explanations or resources for understanding our project structure and coding standards.
- Assist with version control (e.g. git) usage if needed.

### 6.3 Code Review Support

- Offer constructive feedback on pull requests or proposed changes.
- Explain the reasoning behind any requested modifications.
- Guide contributors through the process of updating their submissions.

### 6.4 Documentation Support

- Assist contributors in locating or updating project documentation.
- Encourage and guide contributors who wish to improve our documentation.
- Provide feedback on proposed documentation changes.

### 6.5 Issue Clarification

- Help contributors understand the scope and requirements of open issues.
- Provide additional context or clarification on feature requests or bug reports.

### 6.6 Communication Channels

- Direct contributors to appropriate communication channels (e.g., mailing lists, chat rooms, forums) for project-specific discussions.
- Monitor these channels to provide timely responses to contributor queries.

### 6.7 Mentoring

- Offer mentorship to promising contributors who show consistent interest.
- Provide guidance on best practices, advanced topics, and project goals.

### 6.8 Recognition and Encouragement

- Acknowledge and thank contributors for their efforts, regardless of the outcome.
- Highlight significant contributions in project updates or community announcements.

### 6.9 Conflict Resolution

- Mediate any disagreements between contributors professionally and impartially.
- Ensure discussions remain constructive and aligned with our code of conduct.

### 6.10 Continuous Improvement

- Regularly review and update our contribution processes based on feedback.
- Seek input from contributors on how to improve their experience.

## 7. Cross-Platform Access

### 7.1 Eligibility for Cross-Platform Roles

- Once you have been selected for a staff position on any of our platforms, you become eligible to request staff access on additional platforms.
- This opportunity is open to all current staff members in good standing.

### 7.2 Requesting Additional Platform Access

- If you wish to expand your staff role to other platforms:
  - Express your interest to an admin or through the designated channel for such requests.
  - Specify which additional platform(s) you'd like to moderate.
  - Briefly explain why you're interested in moderating these additional platforms.

### 7.3 Approval Process

- Requests for additional platform access will be reviewed by the admin team.
- Factors considered in the approval process may include:
  - Your performance in your current role
  - Your familiarity with the requested platform
  - The current staffing needs on that platform

### 7.4 Training and Onboarding

- If approved for a cross-platform role, you may be required to undergo platform-specific training.
- Familiarize yourself with any unique rules or moderation tools for the new platform.

### 7.5 Responsibilities of Cross-Platform Staff

- Maintain consistency in rule enforcement across all platforms you moderate.
- Be aware of platform-specific nuances and adjust your approach accordingly.
- Help bridge communication between different platform teams.

### 7.6 Benefits of Cross-Platform Moderation

- Provides a more cohesive user experience across our community's various platforms.
- Allows for more efficient sharing of information and moderation strategies.
- Enhances your skills and versatility as a moderator.

### 7.7 Balancing Responsibilities

- Ensure that taking on additional platforms does not negatively impact your performance on your original platform.
- Communicate with the moderation team if you feel overwhelmed or need to scale back your responsibilities.

### 7.8 Periodic Review

- Your cross-platform roles will be periodically reviewed to ensure effective moderation across all assigned platforms.
- Feedback and additional training may be provided as needed.
